==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/architecture/classes/impl/AttributeSetImpl.java <==
package io.ciera.tool.sql.architecture.classes.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.classes.Attribute;
import io.ciera.tool.sql.architecture.classes.AttributeAccessorSet;
import io.ciera.tool.sql.architecture.classes.AttributeReferenceSet;
import io.ciera.tool.sql.architecture.classes.AttributeSet;
import io.ciera.tool.sql.architecture.classes.ModelInstSet;
import io.ciera.tool.sql.architecture.classes.impl.AttributeAccessorSetImpl;
import io.ciera.tool.sql.architecture.classes.impl.AttributeReferenceSetImpl;
import io.ciera.tool.sql.architecture.classes.impl.ModelInstSetImpl;
import io.ciera.tool.sql.architecture.expression.AttributeAccessSet;
import io.ciera.tool.sql.architecture.expression.WhereSet;
import io.ciera.tool.sql.architecture.expression.impl.AttributeAccessSetImpl;
import io.ciera.tool.sql.architecture.expression.impl.WhereSetImpl;
import io.ciera.tool.sql.architecture.type.TypeReferenceSet;
import io.ciera.tool.sql.architecture.type.impl.TypeReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AttributeSetImpl extends InstanceSet<AttributeSet,Attribute> implements AttributeSet {

    public AttributeSetImpl() {
    }

    public AttributeSetImpl(Comparator<? super Attribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setComp_name( String ref_comp_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setComp_name( ref_comp_name );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setName( String m_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setName( m_name );
    }
    @Override
    public void setComp_package( String ref_comp_package ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setComp_package( ref_comp_package );
    }
    @Override
    public void setType_name( String ref_type_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setType_name( ref_type_name );
    }
    @Override
    public void setType_reference_name( String ref_type_reference_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setType_reference_name( ref_type_reference_name );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setIdentifier( int m_identifier ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setIdentifier( m_identifier );
    }
    @Override
    public void setBase_name( String m_base_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setBase_name( m_base_name );
    }
    @Override
    public void setClass_package( String ref_class_package ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setClass_package( ref_class_package );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setClass_name( ref_class_name );
    }
    @Override
    public void setType_package( String ref_type_package ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setType_package( ref_type_package );
    }
    @Override
    public void setOrder( int m_order ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setOrder( m_order );
    }
    @Override
    public void setDefault_value( String m_default_value ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setDefault_value( m_default_value );
    }


    // selections
    @Override
    public WhereSet R3906_used_as_sort_field_for_Where() throws XtumlException {
        WhereSet whereset = new WhereSetImpl();
        for ( Attribute attribute : this ) whereset.addAll( attribute.R3906_used_as_sort_field_for_Where() );
        return whereset;
    }
    @Override
    public ModelInstSet R410_abstracts_data_for_ModelInst() throws XtumlException {
        ModelInstSet modelinstset = new ModelInstSetImpl();
        for ( Attribute attribute : this ) modelinstset.add( attribute.R410_abstracts_data_for_ModelInst() );
        return modelinstset;
    }
    @Override
    public O_ATTRSet R414_is_transformed_from_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( Attribute attribute : this ) o_attrset.add( attribute.R414_is_transformed_from_O_ATTR() );
        return o_attrset;
    }
    @Override
    public TypeReferenceSet R424_is_typed_by_TypeReference() throws XtumlException {
        TypeReferenceSet typereferenceset = new TypeReferenceSetImpl();
        for ( Attribute attribute : this ) typereferenceset.add( attribute.R424_is_typed_by_TypeReference() );
        return typereferenceset;
    }
    @Override
    public AttributeReferenceSet R4506_has_value_provided_by_AttributeReference() throws XtumlException {
        AttributeReferenceSet attributereferenceset = new AttributeReferenceSetImpl();
        for ( Attribute attribute : this ) attributereferenceset.addAll( attribute.R4506_has_value_provided_by_AttributeReference() );
        return attributereferenceset;
    }
    @Override
    public AttributeReferenceSet R4506_provides_value_for_AttributeReference() throws XtumlException {
        AttributeReferenceSet attributereferenceset = new AttributeReferenceSetImpl();
        for ( Attribute attribute : this ) attributereferenceset.addAll( attribute.R4506_provides_value_for_AttributeReference() );
        return attributereferenceset;
    }
    @Override
    public AttributeAccessorSet R4510_value_accessed_through_AttributeAccessor() throws XtumlException {
        AttributeAccessorSet attributeaccessorset = new AttributeAccessorSetImpl();
        for ( Attribute attribute : this ) attributeaccessorset.addAll( attribute.R4510_value_accessed_through_AttributeAccessor() );
        return attributeaccessorset;
    }
    @Override
    public AttributeAccessSet R788_is_referenced_by_AttributeAccess() throws XtumlException {
        AttributeAccessSet attributeaccessset = new AttributeAccessSetImpl();
        for ( Attribute attribute : this ) attributeaccessset.addAll( attribute.R788_is_referenced_by_AttributeAccess() );
        return attributeaccessset;
    }


    @Override
    public Attribute nullElement() {
        return AttributeImpl.EMPTY_ATTRIBUTE;
    }

    @Override
    public AttributeSet emptySet() {
      return new AttributeSetImpl();
    }

    @Override
    public AttributeSet emptySet(Comparator<? super Attribute> comp) {
      return new AttributeSetImpl(comp);
    }

    @Override
    public List<Attribute> elements() {
        Attribute[] elements = toArray(new Attribute[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/classes/impl/AttributeSetImpl.java <==
package io.ciera.tool.sql.architecture.classes.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.Attribute;
import io.ciera.tool.sql.architecture.classes.AttributeAccessorSet;
import io.ciera.tool.sql.architecture.classes.AttributeReferenceSet;
import io.ciera.tool.sql.architecture.classes.AttributeSet;
import io.ciera.tool.sql.architecture.classes.ModelInstSet;
import io.ciera.tool.sql.architecture.classes.impl.AttributeAccessorSetImpl;
import io.ciera.tool.sql.architecture.classes.impl.AttributeReferenceSetImpl;
import io.ciera.tool.sql.architecture.classes.impl.ModelInstSetImpl;
import io.ciera.tool.sql.architecture.expression.AttributeAccessSet;
import io.ciera.tool.sql.architecture.expression.WhereSet;
import io.ciera.tool.sql.architecture.expression.impl.AttributeAccessSetImpl;
import io.ciera.tool.sql.architecture.expression.impl.WhereSetImpl;
import io.ciera.tool.sql.architecture.type.TypeReferenceSet;
import io.ciera.tool.sql.architecture.type.impl.TypeReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.StructureMemberSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AttributeSetImpl extends InstanceSet<AttributeSet,Attribute> implements AttributeSet {

    public AttributeSetImpl() {
    }

    public AttributeSetImpl(Comparator<? super Attribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setOrder( int m_order ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setOrder( m_order );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setClass_name( ref_class_name );
    }
    @Override
    public void setType_reference_name( String ref_type_reference_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setType_reference_name( ref_type_reference_name );
    }
    @Override
    public void setBase_name( String m_base_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setBase_name( m_base_name );
    }
    @Override
    public void setComp_package( String ref_comp_package ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setComp_package( ref_comp_package );
    }
    @Override
    public void setType_package( String ref_type_package ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setType_package( ref_type_package );
    }
    @Override
    public void setDefault_value( String m_default_value ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setDefault_value( m_default_value );
    }
    @Override
    public void setIdentifier( int m_identifier ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setIdentifier( m_identifier );
    }
    @Override
    public void setType_name( String ref_type_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setType_name( ref_type_name );
    }
    @Override
    public void setName( String m_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setName( m_name );
    }
    @Override
    public void setComp_name( String ref_comp_name ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setComp_name( ref_comp_name );
    }
    @Override
    public void setClass_package( String ref_class_package ) throws XtumlException {
        for ( Attribute attribute : this ) attribute.setClass_package( ref_class_package );
    }


    // selections
    @Override
    public WhereSet R3906_used_as_sort_field_for_Where() throws XtumlException {
        WhereSet whereset = new WhereSetImpl();
        for ( Attribute attribute : this ) whereset.addAll( attribute.R3906_used_as_sort_field_for_Where() );
        return whereset;
    }
    @Override
    public ModelInstSet R410_abstracts_data_for_ModelInst() throws XtumlException {
        ModelInstSet modelinstset = new ModelInstSetImpl();
        for ( Attribute attribute : this ) modelinstset.add( attribute.R410_abstracts_data_for_ModelInst() );
        return modelinstset;
    }
    @Override
    public O_ATTRSet R414_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( Attribute attribute : this ) o_attrset.add( attribute.R414_O_ATTR() );
        return o_attrset;
    }
    @Override
    public TypeReferenceSet R424_is_typed_by_TypeReference() throws XtumlException {
        TypeReferenceSet typereferenceset = new TypeReferenceSetImpl();
        for ( Attribute attribute : this ) typereferenceset.add( attribute.R424_is_typed_by_TypeReference() );
        return typereferenceset;
    }
    @Override
    public AttributeReferenceSet R4506_has_value_provided_by_AttributeReference() throws XtumlException {
        AttributeReferenceSet attributereferenceset = new AttributeReferenceSetImpl();
        for ( Attribute attribute : this ) attributereferenceset.addAll( attribute.R4506_has_value_provided_by_AttributeReference() );
        return attributereferenceset;
    }
    @Override
    public AttributeReferenceSet R4506_provides_value_for_AttributeReference() throws XtumlException {
        AttributeReferenceSet attributereferenceset = new AttributeReferenceSetImpl();
        for ( Attribute attribute : this ) attributereferenceset.addAll( attribute.R4506_provides_value_for_AttributeReference() );
        return attributereferenceset;
    }
    @Override
    public AttributeAccessorSet R4510_value_accessed_through_AttributeAccessor() throws XtumlException {
        AttributeAccessorSet attributeaccessorset = new AttributeAccessorSetImpl();
        for ( Attribute attribute : this ) attributeaccessorset.addAll( attribute.R4510_value_accessed_through_AttributeAccessor() );
        return attributeaccessorset;
    }
    @Override
    public StructureMemberSet R4760_StructureMember() throws XtumlException {
        StructureMemberSet structurememberset = new StructureMemberSetImpl();
        for ( Attribute attribute : this ) structurememberset.add( attribute.R4760_StructureMember() );
        return structurememberset;
    }
    @Override
    public AttributeAccessSet R788_is_referenced_by_AttributeAccess() throws XtumlException {
        AttributeAccessSet attributeaccessset = new AttributeAccessSetImpl();
        for ( Attribute attribute : this ) attributeaccessset.addAll( attribute.R788_is_referenced_by_AttributeAccess() );
        return attributeaccessset;
    }


    @Override
    public Attribute nullElement() {
        return AttributeImpl.EMPTY_ATTRIBUTE;
    }

    @Override
    public AttributeSet emptySet() {
      return new AttributeSetImpl();
    }

    @Override
    public AttributeSet emptySet(Comparator<? super Attribute> comp) {
      return new AttributeSetImpl(comp);
    }

    @Override
    public List<Attribute> elements() {
        Attribute[] elements = toArray(new Attribute[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
